Welcome to ClientVPS Mirrors

Help for package BACCO
Type: Package
Title: Bayesian Analysis of Computer Code Output (BACCO)
Version: 2.1-0
Author: Robin K. S. Hankin
Maintainer: Robin K. S. Hankin <hankin.robin@gmail.com>
Depends: emulator (≥ 1.2-21), calibrator (≥ 1.2-5), approximator (≥ 1.2-6)
Description: The BACCO bundle of packages is replaced by the BACCO package, which provides a vignette that illustrates the constituent packages (emulator, approximator, calibrator) in use.
License: GPL-2 | GPL-3 [expanded from: GPL]
LazyLoad: yes
NeedsCompilation: no
Packaged: 2023-09-10 04:29:00 UTC; rhankin
Repository: CRAN
Date/Publication: 2023-09-10 06:02:37 UTC

Bayesian Analysis of Computer Code Output (BACCO)

Description

The BACCO bundle of packages is replaced by the BACCO package, which provides a vignette that illustrates the constituent packages in use.

Details

This file contains no code: the bundle formerly known as BACCO is now a “virtual” package which requires the constituent packages: emulator, calibrator, and approximator. Package multivator is a standalone package.

Author(s)

Robin K. S. Hankin

Maintainer: Robin K. S. Hankin <hankin.robin@gmail.com>

References

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.